==> telepathy-kde-common-internals-22.04.1-1-aarch64.pkg.tar.xz: usr/lib/cmake/KTp/KTpTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KTp::CommonInternals" for configuration ""
set_property(TARGET KTp::CommonInternals APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KTp::CommonInternals PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "TelepathyLoggerQt;KF5::People;KF5::KIOWidgets;KF5::I18n;KF5::IconThemes;KF5::Notifications"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKTpCommonInternals.so.22.04.1"
  IMPORTED_SONAME_NOCONFIG "libKTpCommonInternals.so.9"
  )

list(APPEND _IMPORT_CHECK_TARGETS KTp::CommonInternals )
list(APPEND _IMPORT_CHECK_FILES_FOR_KTp::CommonInternals "${_IMPORT_PREFIX}/lib/libKTpCommonInternals.so.22.04.1" )

# Import target "KTp::Models" for configuration ""
set_property(TARGET KTp::Models APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KTp::Models PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::ConfigCore;KF5::WidgetsAddons;KF5::IconThemes;KF5::People"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKTpModels.so.22.04.1"
  IMPORTED_SONAME_NOCONFIG "libKTpModels.so.9"
  )

list(APPEND _IMPORT_CHECK_TARGETS KTp::Models )
list(APPEND _IMPORT_CHECK_FILES_FOR_KTp::Models "${_IMPORT_PREFIX}/lib/libKTpModels.so.22.04.1" )

# Import target "KTp::Widgets" for configuration ""
set_property(TARGET KTp::Widgets APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KTp::Widgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::WidgetsAddons;KF5::IconThemes;KF5::KIOFileWidgets;KF5::Notifications;KF5::NotifyConfig;KTp::Models"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKTpWidgets.so.22.04.1"
  IMPORTED_SONAME_NOCONFIG "libKTpWidgets.so.9"
  )

list(APPEND _IMPORT_CHECK_TARGETS KTp::Widgets )
list(APPEND _IMPORT_CHECK_FILES_FOR_KTp::Widgets "${_IMPORT_PREFIX}/lib/libKTpWidgets.so.22.04.1" )

# Import target "KTp::Logger" for configuration ""
set_property(TARGET KTp::Logger APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KTp::Logger PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::Service"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKTpLogger.so.22.04.1"
  IMPORTED_SONAME_NOCONFIG "libKTpLogger.so.9"
  )

list(APPEND _IMPORT_CHECK_TARGETS KTp::Logger )
list(APPEND _IMPORT_CHECK_FILES_FOR_KTp::Logger "${_IMPORT_PREFIX}/lib/libKTpLogger.so.22.04.1" )

# Import target "KTp::OTR" for configuration ""
set_property(TARGET KTp::OTR APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KTp::OTR PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKTpOTR.so.22.04.1"
  IMPORTED_SONAME_NOCONFIG "libKTpOTR.so.9"
  )

list(APPEND _IMPORT_CHECK_TARGETS KTp::OTR )
list(APPEND _IMPORT_CHECK_FILES_FOR_KTp::OTR "${_IMPORT_PREFIX}/lib/libKTpOTR.so.22.04.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> telepathy-kde-common-internals-22.12.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/KTp/KTpTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KTp::CommonInternals" for configuration ""
set_property(TARGET KTp::CommonInternals APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KTp::CommonInternals PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "TelepathyLoggerQt;KF5::People;KF5::KIOWidgets;KF5::I18n;KF5::IconThemes;KF5::Notifications"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKTpCommonInternals.so.22.12.0"
  IMPORTED_SONAME_NOCONFIG "libKTpCommonInternals.so.9"
  )

list(APPEND _cmake_import_check_targets KTp::CommonInternals )
list(APPEND _cmake_import_check_files_for_KTp::CommonInternals "${_IMPORT_PREFIX}/lib/libKTpCommonInternals.so.22.12.0" )

# Import target "KTp::Models" for configuration ""
set_property(TARGET KTp::Models APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KTp::Models PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::ConfigCore;KF5::WidgetsAddons;KF5::IconThemes;KF5::People"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKTpModels.so.22.12.0"
  IMPORTED_SONAME_NOCONFIG "libKTpModels.so.9"
  )

list(APPEND _cmake_import_check_targets KTp::Models )
list(APPEND _cmake_import_check_files_for_KTp::Models "${_IMPORT_PREFIX}/lib/libKTpModels.so.22.12.0" )

# Import target "KTp::Widgets" for configuration ""
set_property(TARGET KTp::Widgets APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KTp::Widgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::WidgetsAddons;KF5::IconThemes;KF5::KIOFileWidgets;KF5::Notifications;KF5::NotifyConfig;KTp::Models"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKTpWidgets.so.22.12.0"
  IMPORTED_SONAME_NOCONFIG "libKTpWidgets.so.9"
  )

list(APPEND _cmake_import_check_targets KTp::Widgets )
list(APPEND _cmake_import_check_files_for_KTp::Widgets "${_IMPORT_PREFIX}/lib/libKTpWidgets.so.22.12.0" )

# Import target "KTp::Logger" for configuration ""
set_property(TARGET KTp::Logger APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KTp::Logger PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::Service"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKTpLogger.so.22.12.0"
  IMPORTED_SONAME_NOCONFIG "libKTpLogger.so.9"
  )

list(APPEND _cmake_import_check_targets KTp::Logger )
list(APPEND _cmake_import_check_files_for_KTp::Logger "${_IMPORT_PREFIX}/lib/libKTpLogger.so.22.12.0" )

# Import target "KTp::OTR" for configuration ""
set_property(TARGET KTp::OTR APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KTp::OTR PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKTpOTR.so.22.12.0"
  IMPORTED_SONAME_NOCONFIG "libKTpOTR.so.9"
  )

list(APPEND _cmake_import_check_targets KTp::OTR )
list(APPEND _cmake_import_check_files_for_KTp::OTR "${_IMPORT_PREFIX}/lib/libKTpOTR.so.22.12.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
